searchData={"items":[{"type":"module","title":"Phoenix.Swoosh","doc":"The main feature provided by this module is the ability to set the HTML and/or\ntext body of an email by rendering templates.\n\nIt utilizes `Phoenix.View` and can work very well both standalone\nand in apps using `Phoenix` framework.\n\n\n`use Phoenix.Swoosh` also accepts a list of options which configures where\ntemplates will be looked up:\n\n  * `:view` - for \"classic\" setup, the view module to use for rendering\n  * `:template_path` - for \"standalone\" setup, given to `Phoenix.View` as `path`\n  * `:template_root` - for \"standalone\" setup, given to `Phoenix.View` as `root`\n  * `:template_namespace` - for \"standalone\" setup, given to `Phoenix.View` as\n  `namespace`\n  * `:layout` - the layout to render the templates in. Must be a tuple,\n  specifying the layout view and the layout name, or `false`\n  * `:formats` - to customize the extensions of the templates. Must be a map,\n  with key being the extension and the value being the body field to set","ref":"Phoenix.Swoosh.html"},{"type":"function","title":"Phoenix.Swoosh.layout/1","doc":"Retrieves the current layout of an email.","ref":"Phoenix.Swoosh.html#layout/1"},{"type":"function","title":"Phoenix.Swoosh.put_layout/2","doc":"Stores the layout for rendering.\n\nThe layout must be a tuple, specifying the layout view and the layout\nname, or false. In case a previous layout is set, `put_layout` also\naccepts the layout name to be given as a string or as an atom. If a\nstring, it must contain the format. Passing an atom means the layout\nformat will be found at rendering time, similar to the template in\n`render_body/3`. It can also be set to `false`. In this case, no\nlayout would be used.","ref":"Phoenix.Swoosh.html#put_layout/2"},{"type":"function","title":"Examples - Phoenix.Swoosh.put_layout/2","doc":"iex> layout(email)\n    false\n\n    iex> email = put_layout email, {LayoutView, \"email.html\"}\n    iex> layout(email)\n    {LayoutView, \"email.html\"}\n\n    iex> email = put_layout email, \"email.html\"\n    iex> layout(email)\n    {LayoutView, \"email.html\"}\n\n    iex> email = put_layout email, :email\n    iex> layout(email)\n    {AppView, :email}","ref":"Phoenix.Swoosh.html#put_layout/2-examples"},{"type":"function","title":"Phoenix.Swoosh.put_new_formats/2","doc":"Stores the formats for rendering if none was stored yet.","ref":"Phoenix.Swoosh.html#put_new_formats/2"},{"type":"function","title":"Phoenix.Swoosh.put_new_layout/2","doc":"Stores the layout for rendering if one was not stored yet.","ref":"Phoenix.Swoosh.html#put_new_layout/2"},{"type":"function","title":"Phoenix.Swoosh.put_new_view/2","doc":"Stores the view for rendering if one was not stored yet.","ref":"Phoenix.Swoosh.html#put_new_view/2"},{"type":"function","title":"Phoenix.Swoosh.put_view/2","doc":"Stores the view for rendering.","ref":"Phoenix.Swoosh.html#put_view/2"},{"type":"function","title":"Phoenix.Swoosh.render_body/3","doc":"Renders the given `template` and `assigns` based on the `email`.\n\nOnce the template is rendered the resulting string is stored on the email\nfields `html_body` and `text_body` depending on the format of the template.\n`.html`, `.htm`, and `.xml` are stored in `html_body`; all other extensions,\n(e.g. `.txt` and `.text`), in `text_body`.","ref":"Phoenix.Swoosh.html#render_body/3"},{"type":"function","title":"Arguments - Phoenix.Swoosh.render_body/3","doc":"* `email` - the `Swoosh.Email` struct.\n\n  * `template` - may be an atom or a string. If an atom, like `:welcome`, it\n    will render both the HTML and text template and stores them respectively on\n    the email. If the template is a string it must contain the extension too,\n    like `welcome.html`.\n\n  * `assigns` - a dictionary with the assigns to be used in the view. Those\n    assigns are merged and have higher order precedence than the email assigns.\n    (`email.assigns`)","ref":"Phoenix.Swoosh.html#render_body/3-arguments"},{"type":"function","title":"Examples - Phoenix.Swoosh.render_body/3","doc":"defmodule Sample.UserEmail do\n      use Phoenix.Swoosh, view: Sample.EmailView\n\n      def welcome(user) do\n        new()\n        |> from(\"tony@stark.com\")\n        |> to(user.email)\n        |> subject(\"Hello, Avengers!\")\n        |> render_body(\"welcome.html\", %{username: user.email})\n      end\n    end\n\nThe example above renders a template `welcome.html` from `Sample.EmailView` and\nstores the resulting string onto the html_body field of the email.\n(`email.html_body`)\n\nIn many cases you may want to set both the html and text body of an email. To\ndo so you can pass the template name as an atom (without the extension):\n\n    def welcome(user) do\n      new()\n      |> from(\"tony@stark.com\")\n      |> to(user.email)\n      |> subject(\"Hello, Avengers!\")\n      |> render_body(:welcome, %{username: user.email})\n    end","ref":"Phoenix.Swoosh.html#render_body/3-examples"},{"type":"function","title":"Layouts - Phoenix.Swoosh.render_body/3","doc":"Templates are often rendered inside layouts. If you wish to do so you will have\nto specify which layout you want to use when using the `Phoenix.Swoosh` module.\n\n    defmodule Sample.UserEmail do\n      use Phoenix.Swoosh, view: Sample.EmailView, layout: {Sample.LayoutView, :email}\n\n      def welcome(user) do\n        new()\n        |> from(\"tony@stark.com\")\n        |> to(user.email)\n        |> subject(\"Hello, Avengers!\")\n        |> render_body(\"welcome.html\", %{username: user.email})\n      end\n    end\n\nThe example above will render the `welcome.html` template inside an\n`email.html` template specified in `Sample.LayoutView`. `put_layout/2` can be\nused to change the layout, similar to how `put_view/2` can be used to change\nthe view.","ref":"Phoenix.Swoosh.html#render_body/3-layouts"},{"type":"extras","title":"Overview","doc":"# Phoenix.Swoosh\n\n[![Elixir CI](https://github.com/swoosh/phoenix_swoosh/actions/workflows/elixir.yml/badge.svg)](https://github.com/swoosh/phoenix_swoosh/actions/workflows/elixir.yml)\n[![Module Version](https://img.shields.io/hexpm/v/phoenix_swoosh.svg)](https://hex.pm/packages/phoenix_swoosh)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/phoenix_swoosh/)\n[![Total Download](https://img.shields.io/hexpm/dt/phoenix_swoosh.svg)](https://hex.pm/packages/phoenix_swoosh)\n[![License](https://img.shields.io/hexpm/l/phoenix_swoosh.svg)](https://github.com/swoosh/phoenix_swoosh/blob/master/LICENSE)\n[![Last Updated](https://img.shields.io/github/last-commit/swoosh/phoenix_swoosh.svg)](https://github.com/swoosh/phoenix_swoosh/commits/master)\n\n`Phoenix.View` + `Swoosh`. ([Discuss about the future post-Phoenix-1.7 here](https://github.com/swoosh/phoenix_swoosh/issues/287))\n\nThis module provides the ability to set the HTML and/or text body of an email by rendering templates.","ref":"readme.html"},{"type":"extras","title":"Installation - Overview","doc":"Add `:phoenix_swoosh` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:phoenix_swoosh, \"~> 1.0\"},\n\n    # without phoenix_html, phoenix_swoosh only works with plain text templates\n    # if you want to use HTML templates\n    # {:phoenix_html, \"~> 3.0\"},\n  ]\nend\n```\n\nYou probably also want to install [`finch`](https://hex.pm/packages/finch),\n[`hackney`](https://hex.pm/packages/hackney) or an HTTP client of your own choice,\nif you are using a provider that `Swoosh` talks to via their HTTP API.\n\nOr [`:gen_smtp`](https://hex.pm/packages/gen_smtp) if you are working with a provider\nthat only works through SMTP.\n\nSee `Swoosh` for more details.","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Overview","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"1. Classic setup - Overview","doc":"Setting up the templates:\n\n```eex\n# path_to/templates/user_notifier/welcome.html.eex\n \n   Welcome to Sample, <%= @name %>! \n \n```\n\n```elixir\n# path_to/views/user_notifier_view.ex\ndefmodule Sample.UserNotifierView do\n  use Phoenix.View, root: \"path_to/templates\"\nend\n```\n\nPassing values to templates:\n\n```elixir\n# path_to/notifiers/user_notifier.ex\ndefmodule Sample.UserNotifier do\n  use Phoenix.Swoosh, view: Sample.UserNotifierView\n\n  def welcome(user) do\n    new()\n    |> from(\"tony@stark.com\")\n    |> to(user.email)\n    |> subject(\"Hello, Avengers!\")\n    |> render_body(\"welcome.html\", %{name: name})\n  end\nend\n```\n\nMaybe with a layout:\n\n```eex\n# path_to/templates/layout/email.html.eex\n \n   \n     <%= @email.subject %> \n   \n   \n    <%= @inner_content %>\n   \n \n```\n\n```elixir\ndefmodule Sample.LayoutView do\n  use Phoenix.View, root: \"path_to/templates\"\nend\n```\n\n```elixir\n# path_to/notifiers/user_notifier.ex\ndefmodule Sample.UserNotifier do\n  use Phoenix.Swoosh,\n    view: Sample.NotifierView,\n    layout: {Sample.LayoutView, :email}\n\n  # ... same welcome ...\nend\n```\n\nLayout can also be added/changed dynamically with `put_new_layout/2` and `put_layout/2`","ref":"readme.html#1-classic-setup"},{"type":"extras","title":"2. Standalone setup - Overview","doc":"```eex\n# path_to/templates/user_notifier/welcome.html.eex\n \n   Welcome to Sample, <%= @name %>! \n \n```\n\n```elixir\n# path_to/notifiers/user_notifier.ex\ndefmodule Sample.UserNotifier do\n  use Phoenix.Swoosh,\n    template_root: \"path_to/templates\",\n    template_path: \"user_notifier\"\n\n  # ... same welcome ...\nend\n```\n\nIn this setup, the notifier module itself serves as the view module\n\n`template_root`, `template_path` and `template_namespace`\nwill be passed to `Phoenix.View` as `root`, `path` and `namespace`.\n\nLayout can be setup the same way as classic setup.","ref":"readme.html#2-standalone-setup"},{"type":"extras","title":"Customization - Overview","doc":"When using either the classic or standalone setup described above, the\nextensions of the templates used can be customized. For example, let's say\nMJML is the desired markup language to use for HTML emails, and there's a\ntemplate such as:\n\n```eex\n# path_to/templates/user_notifier/welcome.mjml.eex\n\n \n   \n     Welcome to Sample, <%= @name %>! \n   \n \n```\n\nPhoenix.Swoosh can be configured to use the \"mjml\" extension when rendering the\nHTML body of the email:\n\n```elixir\n# path_to/notifiers/user_notifier.ex\ndefmodule Sample.UserNotifier do\n  use Phoenix.Swoosh,\n    formats: %{\"mjml\" => :html_body, \"text\" => :text_body}\n\n  # ... same welcome as above ...\nend\n```\n\nThis requires that Phoenix knows how to handle templates using the \"mjml\"\nformat. This can be done by creating a module that exports\n`encode_to_iodata!/1`:\n\n```elixir\ndefmodule Sample.Mjml do\n  def encode_to_iodata!(mjml) do\n    with {:ok, html} <- Mjml.to_html(mjml) do\n      html\n    end\n  end\nend\n```\n\nAnd then configuring Phoenix to use it:\n\n```elixir\nconfig :phoenix, format_encoders: [mjml: Sample.Mjml]\n```\n\nThe above example is using [`mjml`](https://hex.pm/packages/mjml), which would\nneed to be installed as well.","ref":"readme.html#customization"},{"type":"extras","title":"Copyright and License - Overview","doc":"Copyright (c) 2021 Swoosh contributors\n\nReleased under the MIT License, which can be found in [LICENSE.md](./LICENSE.md).","ref":"readme.html#copyright-and-license"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).","ref":"changelog.html"},{"type":"extras","title":"1.2.1 - 2024-01-08 - Changelog","doc":"","ref":"changelog.html#1-2-1-2024-01-08"},{"type":"extras","title":"Maintenance - Changelog","doc":"- Relax `phoenix_html` dependency requirement, allowing `~> 4.0`","ref":"changelog.html#maintenance"},{"type":"extras","title":"1.2.0 - 2023-02-19 - Changelog","doc":"","ref":"changelog.html#1-2-0-2023-02-19"},{"type":"extras","title":"Feature - Changelog","doc":"- Support extension customization @jswanner (#290)\n\nSee customization section in readme for more details.","ref":"changelog.html#feature"},{"type":"extras","title":"1.1.0 - 2022-10-27 - Changelog","doc":"","ref":"changelog.html#1-1-0-2022-10-27"},{"type":"extras","title":"Changes - Changelog","doc":"- Support `phoenix_view` 2.0 @dkln (#279)","ref":"changelog.html#changes"},{"type":"extras","title":"1.0.1 - 2022-02-12 - Changelog","doc":"","ref":"changelog.html#1-0-1-2022-02-12"},{"type":"extras","title":"Changes - Changelog","doc":"- Remove transitive compile-time deps in Phoenix.Swoosh macro @MamesPalmero (#241)","ref":"changelog.html#changes-1"},{"type":"extras","title":"1.0.0 - 2021-09-25 - Changelog","doc":"","ref":"changelog.html#1-0-0-2021-09-25"},{"type":"extras","title":"Added - Changelog","doc":"The setup within a `Phoenix` is now referred to as the\n[classic setup](https://github.com/swoosh/phoenix_swoosh#1-classic-setup).\n\n1.0 adds the ability for the lib to be used outside `Phoenix` apps.\n\nA new setup that doesn't involve a sparate view module is added and is called the standalone setup.\nBoth setups can work outsite `Phoenix` apps thanks to the recently extracted `Phoenix.View`.\n\n#### Standalone setup\n\n```eex\n# path_to/templates/user_notifier/welcome.html.eex\n \n   Welcome to Sample, <%= @name %>! \n \n```\n\n```elixir\n# path_to/notifiers/user_notifier.ex\ndefmodule Sample.UserNotifier do\n  use Phoenix.Swoosh,\n    template_root: \"path_to/templates\",\n    template_path: \"user_notifier\"\n\n  # ... same welcome ...\nend\n```\n\nIn this setup, the notifier module itself serves as the view module\n\n`template_root`, `template_path` and `template_namespace`\nwill be passed to `Phoenix.View` as `root`, `path` and `namespace`.\n\nLayout can be setup the same way as\n[classic setup](https://github.com/swoosh/phoenix_swoosh#1-classic-setup).\n\n---\n\n[Changelog prior to 1.0 can be found on 0.3.x branch](https://github.com/swoosh/phoenix_swoosh/blob/0.3.x/CHANGELOG.md)","ref":"changelog.html#added"},{"type":"extras","title":"Contributing","doc":"# Contributing","ref":"contributing.html"},{"type":"extras","title":"Running tests - Contributing","doc":"Clone the repo and fetch its dependencies:\n\n```bash\n$ git clone https://github.com/swoosh/phoenix_swoosh.git\n$ cd phoenix_swoosh\n$ mix deps.get\n$ mix test\n```","ref":"contributing.html#running-tests"},{"type":"extras","title":"Building docs - Contributing","doc":"Documentation is written into the library, you will find it in the source code,\naccessible from `iex` and of course, it all gets published to\n[hexdocs](http://hexdocs.pm/phoenix_swoosh).\n\n```bash\n$ mix docs\n```","ref":"contributing.html#building-docs"},{"type":"extras","title":"License","doc":"The MIT License (MIT)\n\nCopyright (c) 2016 Swoosh contributors\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.1"}}